@@ -41,9 +41,11 @@ from . import csfr
 from . import diag
 from . import export
 from . import loggly
+from . import logstash
 from . import opbeat
 from . import preflight
 from . import prismic
+from . import recaptcha
 from . import sematext
 
 from .admin import AdminPart
@@ -53,7 +55,9 @@ from .csfr import CSFRPart, csfr_protect, csfr_ensure
 from .diag import DiagPart
 from .export import ExportPart
 from .loggly import LogglyHandler, LogglyPart
+from .logstash import LogstashHandler, LogstashPart
 from .opbeat import OpbeatPart
 from .preflight import PreflightPart
 from .prismic import Prismic
+from .recaptcha import ReCaptchaPart, recaptcha_protect, recaptcha_ensure
 from .sematext import SematextHandler, SematextPart
