@@ -296,6 +296,7 @@ class AdminPart(
             (("GET", "POST"), "/api/admin/login", self.login_api, None, True),
             (("GET", "POST"), "/api/admin/oauth/access_token", self.oauth_access_token_api, None, True),
             (("GET", "POST"), "/api/admin/oauth/login", self.oauth_login_api, None, True),
+            (("POST",), "/api/admin/database/reset", self.database_reset_api, None, True),
             (("GET",), "/api/admin/accounts/me", self.me_account_api, None, True),
             (("GET",), "/api/admin/models/<str:model>", self.show_model_api, None, True),
             (("GET",), "/api/admin/models/<str:model>/<str:_id>", self.show_entity_api, None, True)
@@ -858,7 +859,12 @@ class AdminPart(
             # used as part of the search filter (security measures)
             oauth_client = models.OAuthClient.get_e(
                 client_id = client_id,
-                redirect_uri = redirect_uri
+                **{
+                    "$or": [
+                        dict(redirect_uri = redirect_uri),
+                        dict(redirect_uri = "http://*")
+                    ]
+                }
             )
 
             # asserts that the requested scope is valid for the associated
@@ -914,9 +920,10 @@ class AdminPart(
 
     @appier.ensure(context = "admin")
     def do_oauth_authorize(self):
-        if not self.owner.admin_oauth: raise appier.SecurityError(
-            message = "OAuth not allowed"
-        )
+        if not self.owner.admin_oauth:
+            raise appier.SecurityError(
+                message = "OAuth not allowed"
+            )
 
         client_id = self.field("client_id", mandatory = True)
         redirect_uri = self.field("redirect_uri", mandatory = True)
@@ -929,10 +936,16 @@ class AdminPart(
         account = self.account_c.from_session()
         oauth_client = models.OAuthClient.get_e(
             client_id = client_id,
-            redirect_uri = redirect_uri
+            **{
+                "$or": [
+                    dict(redirect_uri = redirect_uri),
+                    dict(redirect_uri = "http://*")
+                ]
+            }
         )
         oauth_token = oauth_client.build_token_s(
             username = account.username,
+            redirect_uri = redirect_uri,
             scope = scope_l
         )
 
@@ -981,7 +994,12 @@ class AdminPart(
         oauth_client = models.OAuthClient.get_e(
             client_id = client_id,
             client_secret = client_secret,
-            redirect_uri = redirect_uri
+            **{
+                "$or": [
+                    dict(redirect_uri = redirect_uri),
+                    dict(redirect_uri = "http://*")
+                ]
+            }
         )
 
         if grant_type == "authorization_code":
@@ -2158,6 +2176,11 @@ class AdminPart(
     def oauth_login_api(self):
         return self.oauth_login()
 
+    def database_reset_api(self):
+        adapter = self.get_adapter()
+        adapter.drop_db()
+        return True
+
     def login_api(self):
         # verifies if the current administration interface is
         # available and if that's not the cases raises an error
