@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2019 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -46,7 +46,7 @@ class Facebook(object):
 
     def has_facebook(self):
         try: import facebook
-        except: facebook = None
+        except Exception: facebook = None
         if not facebook: return False
         if not appier.conf("FB_ID"): return False
         if not appier.conf("FB_SECRET"): return False
@@ -104,7 +104,7 @@ class Facebook(object):
             account.save()
 
         account.touch_login_s()
-        account._set_session()
+        account._set_account()
 
         return account
 
