@@ -86,6 +86,18 @@ class DiagRequest(base.DiagBase):
         immutable = True
     )
 
+    in_length = appier.field(
+        type = int,
+        index = "all",
+        immutable = True
+    )
+
+    out_length = appier.field(
+        type = int,
+        index = "all",
+        immutable = True
+    )
+
     browser = appier.field(
         index = "all",
         immutable = True
