@@ -231,6 +231,8 @@ class DiagPart(appier.Part):
             code = self.request.code,
             protocol = self.request.protocol,
             duration = self.request.duration,
+            in_length = self.request.in_length,
+            out_length = self.request.out_length,
             browser = self._browser,
             headers = self.request.in_headers,
             browser_info = self.request.browser_info,
@@ -302,6 +304,8 @@ class DiagPart(appier.Part):
         item.update(
             protocol = self.request.protocol,
             duration = self.request.duration,
+            in_length = self.request.in_length,
+            out_length = self.request.out_length,
             browser = self._browser,
             in_headers = self.request.in_headers,
             out_headers = self.request.out_headers,
@@ -328,7 +332,9 @@ class DiagPart(appier.Part):
             item["exception"] = dict(
                 name = exception.__class__.__name__,
                 uid = exception.uid if hasattr(exception, "uid") else None,
-                message = exception.message if hasattr(exception, "message") else None
+                message = exception.message if hasattr(exception, "message") else None,
+                code = exception.code if hasattr(exception, "code") else None,
+                meta = exception.meta if hasattr(exception, "meta") else None
             )
         if self.request.stacktrace:
             item["stacktrace"] = self.request.stacktrace
@@ -342,7 +348,7 @@ class DiagPart(appier.Part):
         return item
 
     @property
-    def _timestamp(self, format = "%Y-%m-%dT%H:%M:%S"):
+    def _timestamp(self, format = "%Y-%m-%dT%H:%M:%S.%fZ"):
         now = datetime.datetime.utcnow()
         return now.strftime(format)
 
